<?php
  // $Id: movies_admin.inc,v 1.2 2007/08/26 21:04:22 ianbezanson Exp $
  
  /********************************************************************
   * movies_admin.inc
   *
   * Helper functions for admin pages
   *
   ********************************************************************/

  /**
   * movies_admin()
   *
   * Gathers and generates a movie table with administrative
   * functionality (add, edit, delete).
   */
  function movies_admin()
  {
    list($header,$rows) = show_movies(1);

    //Build output based on a table theme
    $output = l('View Movie Wishlist', 'admin/movies/wishlist', NULL);
    $output .= theme('table', $header, $rows);
    $output .= l('Add New Movie', 'admin/movies/edit');
    $output .= theme('pager', NULL, variable_get('movies_paginate', '50'));
    return $output;
  }

  /**
   * movies_wishlist()
   *
   * Gathers and generates a movie table with administrative
   * functionality (add, edit, delete).
   */
  function movies_wishlist()
  {
    list($header,$rows) = show_movies(1,1);

    //Build output based on a table theme
    $output = l('View Movies', 'admin/movies', NULL) . ' | ';
    $output .= l('View Conflicting Movies', 'admin/movies/wishlist/conflicts', NULL);
    $output .= theme('table', $header, $rows);
    $output .= l('Add New Wishlist Movie', 'admin/movies/wishlist/edit');
    $output .= theme('pager', NULL, variable_get('movies_paginate', '50'));
    return $output;
  }
  
  /**
   * movies_edit()
   *
   * Allows administrator to add or edit a movie.  Presents a Drupal 
   * form
   */
  function movies_edit( $movie_id = 0 )
  {
    if ($movie_id != 0)
    {
      $movies = movies_find($movie_id);
      if($movies)
      {
        $movielist = db_fetch_object($movies);
      }
    }

    $form['movies'] = array(
      '#type' => 'fieldset',
      '#title' => t('Movies Admin')
    );

    $form['movies']['movie_name'] = array(
      '#type' => 'textfield',
      '#title' => t('Movie Name'),
      '#size' => 25,
      '#maxlength' => 25,
      '#description' => t("What is the name of this film?"),
      '#default_value' => $movielist->movie_name,
      '#required' => true,
    );
    
    $form['movies']['movie_genre'] = array(
      '#type' => 'textfield',
      '#title' => t('Movie Genre'),
      '#size' => 25,
      '#maxlength' => 25,
      '#description' => t("What genre is this film?"),
      '#default_value' => $movielist->movie_genre,
    );
    
    $form['movies']['movie_year'] = array(
      '#type' => 'textfield',
      '#title' => t('Release Year'),
      '#size' => 4,
      '#maxlength' => 4,
      '#description' => t("What year was the film released?"),
      '#default_value' => $movielist->movie_year,
    );
    
    $form['movies']['movie_format'] = array(
      '#type' => 'textfield',
      '#title' => t('Movie Format'),
      '#size' => 25,
      '#maxlength' => 25,
      '#description' => t("What format is this film in (e.g DVD, VHS, DiVX, etc)?"),
      '#default_value' => $movielist->movie_format,
    );
    
    $form['movies']['imdb_link'] = array(
      '#type' => 'textfield',
      '#title' => t('IMDB Link'),
      '#size' => 10,
      '#maxlength' => 10,
      '#description' => t("What is the IMDB number for this film (e.g. tt0390022)?"),
      '#default_value' => $movielist->imdb_link,
    );
    
    
    $form['movie_id'] = array(
      '#type' => 'hidden',
      '#value' => $movielist->movie_id,
    );

    //We only want to show the edit and delete buttons if user is doing an edit
    if ($movielist->movie_id != 0)
    {
      $form['movies']['submit_button'] = array(
        '#type' => 'submit',
        '#value' => 'Save Movie',
      );

      $form['movies']['deleteMovie'] = array(
        '#type' => 'button',
        '#value' => 'Delete Movie',
      );
    }
    
    else
    {
      $form['movies']['submit_button'] = array(
        '#type' => 'submit',
        '#value' => 'Add Movie',
      );
    }
    return $form;
  
  }

  /**
   * Drupal form_validate() hook
   *
   * Validate the edit form to check that movie year is numeric, and
   * to send user off to delete confirmation page if they'd clicked 
   * delete.
   */
  function movies_edit_validate($form_id, $form_values)
  {
    switch ($form_values['op']) {
      case 'Delete Movie':
        drupal_goto('admin/movies/delete/' . $form_values['movie_id']);
        break;
    }
    if(!is_numeric($form_values['movie_year']))
    {
      form_set_error('movie_year', 'Movie Year Must Be Numeric.');
    }
  }

  /**
   * Drupal form_submit() hook
   *
   * If the movie_id is set to 0 (i.e. this is a new movie), we'll add
   * the movie to the database.  Otherwise, we will update the table
   * with the submitted form fields.
   */
  function movies_edit_submit($form_id, $form_values)
  {
    $movie_id     = $form_values['movie_id'];
    $movie_name   = $form_values['movie_name'];
    $movie_genre  = $form_values['movie_genre'];
    $movie_year   = $form_values['movie_year'];
    $movie_format = $form_values['movie_format'];
    $imdb_link    = $form_values['imdb_link'];
    
    if($movie_id == 0)
    {
      if (!movies_add($movie_name, $movie_genre, $movie_year, $movie_format, $imdb_link))
      {
        drupal_set_message('Unable to add movie ' . $movie_name . '. Database error');
        watchdog('Movies', 'Error Adding Movie!');
      }
      else drupal_set_message('Successfully added movie ' . $movie_name . '!');
    }
    else
    {
      if (!movies_update($movie_id, $movie_name, $movie_genre, $movie_year, $movie_format, $imdb_link))
      {
        drupal_set_message('Unable to update movie ' . $movie_name . '. Database error');
        watchdog('Movies', 'Error Updating Movie!');
      }
      else drupal_set_message('Successfully updated movie ' . $movie_name . '!');
    }
    drupal_goto('admin/movies');
  }

  /**
   * movies_delete()
   *
   * Presents the user with a confirmation form to delete the movie
   * associated with the supplied movie ID.  We do a quick sanity check
   * to see if the admin supplied a movie ID, if not, we bounce them 
   * back to the main movies admin page.
   */
  function movies_delete( $movie_id = 0 )
  {
    if ($_POST['op'] == 'Cancel')
    {
      drupal_goto('admin/movies');
      exit();
    }

    if ($movie_id == 0)
    {
      drupal_set_message('Cannot delete a movie without a Movie ID!');
      drupal_goto("admin/movies");
      exit();
    }

    $form['movie_id'] = array(
      '#type'  => 'hidden',
      '#value' => $movie_id,
    );

    $form['movie_delete'] = array(
      '#type'  => 'fieldset',
      '#title' => 'Movies Admin - Delete Movie ' . $movie_id,
    );

    $form['movie_delete']['label'] = array(
      '#value' => 'Are you sure you want to delete this?<br />',
    );
    
    $form['movie_delete']['submitButton'] = array(
      '#type'  => 'submit',
      '#value' => 'Confirm Delete',
    );

    $form['movie_delete']['cancelButton'] = array(
      '#type'  => 'button',
      '#value' => 'Cancel',
    );

    return $form;
  }

  /**
   * Drupal form_submit() hook
   *
   * We try to delete the movie, and then send the user back to the 
   * main movies admin page.
   */
  function movies_delete_submit($form_id, $form_values)
  {
    $movie_id = $form_values['movie_id'];
    if(!movies_remove($movie_id))
    {
      drupal_set_message('Unable to delete movie ' . $movie_id . '.');
      watchdog('Movies', 'Error Deleting Movie!');
    }
    drupal_goto('admin/movies');
  }
  
