<?php
  // $Id: movies_wishlist_admin.inc,v 1.2 2007/08/26 21:04:22 ianbezanson Exp $
  
  /********************************************************************
   * movies_wishlist_admin.inc
   *
   * Helper functions for admin pages
   *
   ********************************************************************/

  /**
   * wishlist_add_to_movies()
   *
   * Add movies to your wishlist (can later be checked off as added, and
   * are automatically added to you movie list).
   */
  function wishlist_add_to_movies( $movie_id = 0 )
  {
    if ($_POST['op'] == 'Cancel')
    {
      drupal_goto('admin/movies/wishlist');
      exit();
    }

    if ($movie_id == 0)
    {
      drupal_set_message('Cannot add to movies without a Movie ID!');
      drupal_goto("admin/movies/wishlist");
      exit();
    }

    $form['movie_id'] = array(
      '#type'  => 'hidden',
      '#value' => $movie_id,
    );

    $form['wishlist_add_to_movies'] = array(
      '#type'  => 'fieldset',
      '#title' => 'Movies Admin - Add Movie ' . $movie_id,
    );

    $form['wishlist_add_to_movies']['label'] = array(
      '#value' => 'Are you sure you want to delete this?<br />',
    );
    
    $form['wishlist_add_to_movies']['submitButton'] = array(
      '#type'  => 'submit',
      '#value' => 'Add To Movies',
    );

    $form['wishlist_add_to_movies']['cancelButton'] = array(
      '#type'  => 'button',
      '#value' => 'Cancel',
    );
    return $form;
  }

  /**
   * Drupal form_submit() hook
   *
   * We try to add the movie, and then send the user back to the 
   * main movie wishlist admin page.
   */
  function wishlist_add_to_movies_submit($form_id, $form_values)
  {
    $movie_id = $form_values['movie_id'];
    if(!wishlist_to_movie($movie_id))
    {
      drupal_set_message('Unable to add movie ' . $movie_id . ' from wishlist.');
      watchdog('Movies', 'Error Adding Movie From Wishlist!');
    }
    drupal_goto('admin/movies/wishlist');
  }
  
  /**
   * movies_wishlist_edit()
   *
   * Allows administrator to add or edit a movie.  Presents a Drupal 
   * form
   */
  function movies_wishlist_edit( $movie_id = 0 )
  {
    if ($movie_id != 0)
    {
      $movies = wishlist_movies_find($movie_id);
      if($movies)
      {
        $movielist = db_fetch_object($movies);
      }
    }

    $form['movies'] = array(
      '#type' => 'fieldset',
      '#title' => t('Movies Admin')
    );

    $form['movies']['movie_name'] = array(
      '#type' => 'textfield',
      '#title' => t('Movie Name'),
      '#size' => 25,
      '#maxlength' => 25,
      '#description' => t("What is the name of this film?"),
      '#default_value' => $movielist->movie_name,
      '#required' => true,
    );
    
    $form['movies']['movie_genre'] = array(
      '#type' => 'textfield',
      '#title' => t('Movie Genre'),
      '#size' => 25,
      '#maxlength' => 25,
      '#description' => t("What genre is this film?"),
      '#default_value' => $movielist->movie_genre,
    );
    
    $form['movies']['movie_year'] = array(
      '#type' => 'textfield',
      '#title' => t('Release Year'),
      '#size' => 4,
      '#maxlength' => 4,
      '#description' => t("What year was the film released?"),
      '#default_value' => $movielist->movie_year,
    );
    
    $form['movies']['movie_format'] = array(
      '#type' => 'textfield',
      '#title' => t('Movie Format'),
      '#size' => 25,
      '#maxlength' => 25,
      '#description' => t("What format is this film in (e.g DVD, VHS, DiVX, etc)?"),
      '#default_value' => $movielist->movie_format,
    );
    
    $form['movies']['imdb_link'] = array(
      '#type' => 'textfield',
      '#title' => t('IMDB Link'),
      '#size' => 10,
      '#maxlength' => 10,
      '#description' => t("What is the IMDB number for this film (e.g. tt0390022)?"),
      '#default_value' => $movielist->imdb_link,
    );
    
    
    $form['movie_id'] = array(
      '#type' => 'hidden',
      '#value' => $movielist->movie_id,
    );

    //We only want to show the edit and delete buttons if user is doing an edit
    if ($movielist->movie_id != 0)
    {
      $form['movies']['submit_button'] = array(
        '#type' => 'submit',
        '#value' => 'Save Movie',
      );

      $form['movies']['deleteMovie'] = array(
        '#type' => 'button',
        '#value' => 'Delete Movie',
      );
    }
    
    else
    {
      $form['movies']['submit_button'] = array(
        '#type' => 'submit',
        '#value' => 'Add Movie',
      );
    }
    return $form;
  
  }

  /**
   * Drupal form_validate() hook
   *
   * Validate the edit form to check that movie year is numeric, and
   * to send user off to delete confirmation page if they'd clicked 
   * delete.
   */
  function movies_wishlist_edit_validate($form_id, $form_values)
  {
    switch ($form_values['op']) {
      case 'Delete Movie':
        drupal_goto('admin/movies/wishlist/delete/' . $form_values['movie_id']);
        break;
    }
    if(!is_numeric($form_values['movie_year']))
    {
      form_set_error('movie_year', 'Movie Year Must Be Numeric.');
    }
  }

  /**
   * Drupal form_submit() hook
   *
   * If the movie_id is set to 0 (i.e. this is a new movie), we'll add
   * the movie to the wishlist database.  Otherwise, we will update the table
   * with the submitted form fields.
   */
  function movies_wishlist_edit_submit($form_id, $form_values)
  {
    $movie_id     = $form_values['movie_id'];
    $movie_name   = $form_values['movie_name'];
    $movie_genre  = $form_values['movie_genre'];
    $movie_year   = $form_values['movie_year'];
    $movie_format = $form_values['movie_format'];
    $imdb_link    = $form_values['imdb_link'];
    
    if($movie_id == 0)
    {
      if (!wishlist_movies_add($movie_name, $movie_genre, $movie_year, $movie_format, $imdb_link))
      {
        drupal_set_message('Unable to add wishlist movie ' . $movie_name . '. Database error');
        watchdog('Movies', 'Error Adding Wishlist Movie!');
      }
      else drupal_set_message('Successfully added wishlist movie ' . $movie_name . '!');
    }
    else
    {
      if (!wishlist_movies_update($movie_id, $movie_name, $movie_genre, $movie_year, $movie_format, $imdb_link))
      {
        drupal_set_message('Unable to update wishlist movie ' . $movie_name . '. Database error');
        watchdog('Movies', 'Error Updating Wishlist Movie!');
      }
      else drupal_set_message('Successfully updated wishlist movie ' . $movie_name . '!');
    }
    drupal_goto('admin/movies/wishlist');
  }

  /**
   * movies_wishlist_delete()
   *
   * Presents the user with a confirmation form to delete the wishlist movie
   * associated with the supplied movie ID.  We do a quick sanity check
   * to see if the admin supplied a movie ID, if not, we bounce them 
   * back to the main movies admin page.
   */
  function movies_wishlist_delete( $movie_id = 0 )
  {
    if ($_POST['op'] == 'Cancel')
    {
      drupal_goto('admin/movies/wishlist');
      exit();
    }

    if ($movie_id == 0)
    {
      drupal_set_message('Cannot delete a wishlist movie without a Movie ID!');
      drupal_goto("admin/movies/wishlist");
      exit();
    }

    $form['movie_id'] = array(
      '#type'  => 'hidden',
      '#value' => $movie_id,
    );

    $form['movie_delete'] = array(
      '#type'  => 'fieldset',
      '#title' => 'Movies Admin - Delete Wishlist Movie ' . $movie_id,
    );

    $form['movie_delete']['label'] = array(
      '#value' => 'Are you sure you want to delete this?<br />',
    );
    
    $form['movie_delete']['submitButton'] = array(
      '#type'  => 'submit',
      '#value' => 'Confirm Delete',
    );

    $form['movie_delete']['cancelButton'] = array(
      '#type'  => 'button',
      '#value' => 'Cancel',
    );

    return $form;
  }

  /**
   * Drupal form_submit() hook
   *
   * We try to delete the wishlist movie, and then send the user back to the 
   * main movie wishlist admin page.
   */
  function movies_wishlist_delete_submit($form_id, $form_values)
  {
    $movie_id = $form_values['movie_id'];
    if(!wishlist_movies_remove($movie_id))
    {
      drupal_set_message('Unable to delete wishlist movie ' . $movie_id . '.');
      watchdog('Movies', 'Error Deleting Wishlist Movie!');
    }
    drupal_goto('admin/movies/wishlist');
  }
  
  /**
   * movies_wishlist_conflicts()
   *
   * Checks for conflicts between the Wishlist and regular Movie DB
   */
  function movies_wishlist_conflicts()
  {
    $output = '';
    //Build a header with all required columns
    $header = array(
      array('data' => t('Movie Name'), 'field' => 'movie_name', 'sort' => 'asc') , 
      array('data' => t('Genre'), 'field' => 'movie_genre') , 
      array('data' => t('Year'), 'field' => 'movie_year') , 
      array('data' => t('Format'), 'field' => 'movie_format') , 
      array('data' => t('IMDB'), 'field' => 'imdb_link') , 
      array('data' => t('Date Added'), 'field' => 'date_added') , 
      array('data' => t('Fix Conflict?')) , 
    );
    
    $sql = tablesort_sql($header);
    $movies = get_conflicts($sql);

    if(db_num_rows($movies) > 0)
    {
      $i = 0;
      while ($movielist = db_fetch_object($movies))
      {
        $rows[$i] = array(
          array('data' => $movielist->movie_name),
          array('data' => $movielist->movie_genre),
          array('data' => $movielist->movie_year),
          array('data' => $movielist->movie_format),
          array('data' => $movielist->imdb_link),
          array('data' => date("M jS, Y", $movielist->date_added)),
          array('data' => l(t('Fix This!'), 'admin/movies/wishlist/fix/' . $movielist->movie_id)),
        );
      }
      $output .= theme('table', $header, $rows);
      $output .= theme('pager', NULL, variable_get('movies_paginate', '50'));
    }
    else
    {
      $output .= theme('table', $header, $rows);
      $output .= theme('pager', NULL, variable_get('movies_paginate', '50'));
      $output .= t('<br /><b>There are no conflicts between the Movie list and the Movie Wishlist!</b>');
    }
    return $output;
  }
  
  /**
   * fix_conflict()
   *
   * If a conflict exists between a movie and a wishlist item (we're
   * active in both dbs), the user can choose to fix the wishlist.
   */
  function fix_conflict( $movie_id = 0 )
  {
    if ($_POST['op'] == 'Cancel')
    {
      drupal_goto('admin/movies/wishlist/conflicts');
      exit();
    }

    if ($movie_id == 0)
    {
      drupal_set_message('Cannot fix a conflict without a Movie ID!');
      drupal_goto("admin/movies/wishlist/conflicts");
      exit();
    }

    $form['movie_id'] = array(
      '#type'  => 'hidden',
      '#value' => $movie_id,
    );

    $form['movie_delete'] = array(
      '#type'  => 'fieldset',
      '#title' => 'Movies Admin - Fix Conflict For ' . $movie_id,
    );

    $form['movie_delete']['label'] = array(
      '#value' => 'Are you sure you want to fix this conflict?<br />',
    );
    
    $form['movie_delete']['submitButton'] = array(
      '#type'  => 'submit',
      '#value' => 'Confirm Conflict Resolution',
    );

    $form['movie_delete']['cancelButton'] = array(
      '#type'  => 'button',
      '#value' => 'Cancel',
    );

    return $form;
  }

  /**
   * Drupal form_submit() hook
   *
   * We try to fix the conflict, and then send the user back to the 
   * main conflict page.
   */
  function fix_conflict_submit($form_id, $form_values)
  {
    $movie_id = $form_values['movie_id'];
    if(!conflict_resolve_db($movie_id))
    {
      drupal_set_message('Unable to resolve conflict of wishlist movie ' . $movie_id . '.');
      watchdog('Movies', 'Error Resolving Conflict With Wishlist Movie!');
    }
    drupal_goto('admin/movies/wishlist/conflicts');
  }
  
